recovery

package
v0.2.42 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 25, 2026 License: MIT Imports: 3 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func LogPanic

func LogPanic(scope string, panicValue any, attrs ...any)

LogPanic writes a structured panic log with a full stack trace.

func Recover

func Recover(scope string, attrs ...any)

Recover logs and swallows a panic inside deferred cleanup.

Types

This section is empty.

Jump to